1.0.15 (unreleased)
-------------------

- Nothing changed yet.


1.0.14 (2020-09-25)
-------------------

- Fix for ar -> winston conversion and changed get_balance to self.balance property


1.0.13 (2020-08-19)
-------------------

- tested for data < 1 chunk and data > 1 chunk scenarios


1.0.12 (2020-08-19)
-------------------

- Fixed upload_in_body error


1.0.11 (2020-08-18)
-------------------

- Fixed chunking error again


1.0.10 (2020-08-18)
-------------------

- Fixed chunking error


1.0.9 (2020-08-12)
------------------

- changed to use requests content not text member


1.0.8 (2020-08-12)
------------------

- fix get_data encoding error


1.0.7 (2020-08-12)
------------------

- added auto decode of tags from json


1.0.6 (2020-08-12)
------------------

- Replace pycrypto with pycryptodome for Python3 compatibility 


1.0.5 (2020-08-12)
------------------

- Replace pycrypto with pycryptodome for Python3 compatibility 


1.0.4 (2020-08-12)
------------------

- updated get_signature_data() to support old style data_root calculations


1.0.3 (2020-08-07)
------------------

- tweaks and bug fixes for chunk uploading and get_data method
